@@ -6,14 +6,14 @@
 
 # An anonymized string *must* be an md5 hash, so must have exactly 32 characters
 anonymized_string_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "type": "string",
     "minLength": 32,
     "maxLength": 32,
 }
 
 anonymized_datasource_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-datasource",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "oneOf": [
@@ -32,7 +32,7 @@ anonymized_datasource_schema = {
 }
 
 anonymized_class_info_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-class-info",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "oneOf": [
@@ -45,13 +45,14 @@ anonymized_class_info_schema = {
             },
             "additionalProperties": True,
             # we don't want this to be true, but this is required to allow show_cta_footer
+            # Note AJB-20201218 show_cta_footer was removed in v 0.9.9 via PR #1249
             "required": ["parent_class"],
         }
     ],
 }
 
 anonymized_store_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-store",
     "definitions": {
         "anonymized_string": anonymized_string_schema,
@@ -75,7 +76,7 @@ anonymized_store_schema = {
 }
 
 anonymized_action_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-action",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "oneOf": [
@@ -93,7 +94,7 @@ anonymized_action_schema = {
 }
 
 anonymized_validation_operator_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-validation-operator",
     "definitions": {
         "anonymized_string": anonymized_string_schema,
@@ -119,15 +120,15 @@ anonymized_validation_operator_schema = {
 }
 
 empty_payload_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "type": "object",
     "properties": {},
     "additionalProperties": False,
 }
 
 anonymized_data_docs_site_schema = {
-    "$schema": "http://json-schema.org/schema#",
-    "title": "anonymized-validation-operator",
+    "$schema": "http://json-schema.org/draft-04/schema#",
+    "title": "anonymized-data-docs-site",
     "definitions": {
         "anonymized_string": anonymized_string_schema,
         "anonymized_class_info": anonymized_class_info_schema,
@@ -153,8 +154,8 @@ anonymized_data_docs_site_schema = {
 }
 
 anonymized_expectation_suite_schema = {
-    "$schema": "http://json-schema.org/schema#",
-    "title": "anonymized-expectation_suite_schema",
+    "$schema": "http://json-schema.org/draft-04/schema#",
+    "title": "anonymized-expectation-suite-schema",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "oneOf": [
         {
@@ -165,7 +166,28 @@ anonymized_expectation_suite_schema = {
                 "anonymized_expectation_type_counts": {"type": "object"},
             },
             "additionalProperties": False,
-        }
+        },
+        {
+            "type": "object",
+            "properties": {
+                "anonymized_name": {"$ref": "#/definitions/anonymized_string"},
+                "expectation_count": {"type": "number"},
+                "anonymized_expectation_counts": {
+                    "type": "array",
+                    "items": {
+                        "type": "object",
+                        "properties": {
+                            "expectation_type": {"type": "string"},
+                            "anonymized_expectation_type": {
+                                "$ref": "#/definitions/anonymized_string"
+                            },
+                            "count": {"type": "number"},
+                        },
+                    },
+                },
+            },
+            "additionalProperties": False,
+        },
     ],
 }
 
@@ -218,7 +240,6 @@ init_payload_schema = {
         "version_info",
         "anonymized_datasources",
         "anonymized_stores",
-        "anonymized_validation_operators",
         "anonymized_data_docs_sites",
         "anonymized_expectation_suites",
     ],
@@ -226,7 +247,7 @@ init_payload_schema = {
 }
 
 anonymized_batch_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "anonymized-batch",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "oneOf": [
@@ -256,7 +277,7 @@ anonymized_batch_schema = {
 }
 
 run_validation_operator_payload_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "definitions": {
         "anonymized_string": anonymized_string_schema,
         "anonymized_batch": anonymized_batch_schema,
@@ -275,7 +296,7 @@ run_validation_operator_payload_schema = {
 }
 
 save_or_edit_expectation_suite_payload_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "definitions": {"anonymized_string": anonymized_string_schema},
     "type": "object",
     "properties": {
@@ -287,12 +308,46 @@ save_or_edit_expectation_suite_payload_schema = {
     "additionalProperties": False,
 }
 
-cli_new_ds_choice_payload = {
-    "$schema": "http://json-schema.org/schema#",
+cli_suite_expectation_suite_payload_schema = {
+    "$schema": "http://json-schema.org/draft-04/schema#",
+    "definitions": {"anonymized_string": anonymized_string_schema},
+    "type": "object",
+    "properties": {
+        "anonymized_expectation_suite_name": {
+            "$ref": "#/definitions/anonymized_string"
+        },
+        "api_version": {"type": "string", "maxLength": 256},
+        "cancelled": {
+            "type": ["boolean", "null"],
+        },
+    },
+    "required": ["anonymized_expectation_suite_name"],
+    "additionalProperties": False,
+}
+
+cli_payload_schema = {
+    "$schema": "http://json-schema.org/draft-04/schema#",
+    "title": "cli-payload",
+    "type": "object",
+    "properties": {
+        "api_version": {
+            "type": "string",
+            "maxLength": 256,
+        },
+        "cancelled": {
+            "type": ["boolean", "null"],
+        },
+    },
+    "additionalProperties": False,
+}
+
+cli_new_ds_choice_payload_schema = {
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "type": "object",
     "properties": {
         "type": {"type": "string", "maxLength": 256},
         "db": {"type": "string", "maxLength": 256},
+        "api_version": {"type": "string", "maxLength": 256},
     },
     "required": ["type"],
     "additionalProperties": False,
@@ -300,7 +355,7 @@ cli_new_ds_choice_payload = {
 
 
 datasource_sqlalchemy_connect_payload = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "type": "object",
     "properties": {
         "anonymized_name": {"type": "string", "maxLength": 256},
@@ -311,7 +366,7 @@ datasource_sqlalchemy_connect_payload = {
 }
 
 usage_statistics_record_schema = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "definitions": {
         "anonymized_string": anonymized_string_schema,
         "anonymized_datasource": anonymized_datasource_schema,
@@ -326,7 +381,9 @@ usage_statistics_record_schema = {
         "anonymized_batch": anonymized_batch_schema,
         "anonymized_expectation_suite": anonymized_expectation_suite_schema,
         "save_or_edit_expectation_suite_payload": save_or_edit_expectation_suite_payload_schema,
-        "cli_new_ds_choice_payload": cli_new_ds_choice_payload,
+        "cli_suite_expectation_suite_payload": cli_suite_expectation_suite_payload_schema,
+        "cli_payload": cli_payload_schema,
+        "cli_new_ds_choice_payload": cli_new_ds_choice_payload_schema,
         "datasource_sqlalchemy_connect_payload": datasource_sqlalchemy_connect_payload,
     },
     "type": "object",
@@ -350,9 +407,7 @@ usage_statistics_record_schema = {
         {
             "type": "object",
             "properties": {
-                "event": {
-                    "enum": ["data_context.save_expectation_suite", "cli.suite.edit"]
-                },
+                "event": {"enum": ["data_context.save_expectation_suite"]},
                 "event_payload": {
                     "$ref": "#/definitions/save_or_edit_expectation_suite_payload"
                 },
@@ -404,27 +459,92 @@ usage_statistics_record_schema = {
                     "enum": [
                         "data_context.build_data_docs",
                         "data_context.open_data_docs",
-                        "cli.suite.demo",
-                        "cli.suite.list",
-                        "cli.suite.new",
-                        "cli.suite.scaffold",
-                        "cli.store.list",
-                        "cli.project.check_config",
-                        "cli.checkpoint.list",
-                        "cli.datasource.list",
-                        "cli.datasource.new",
-                        "cli.datasource.profile",
-                        "cli.validation_operator.list",
-                        "cli.validation_operator.run",
-                        "cli.docs.build",
-                        "cli.docs.clean",
-                        "cli.docs.list",
-                        "cli.init.create",
                     ],
                 },
                 "event_payload": {"$ref": "#/definitions/empty_payload"},
             },
         },
+        {
+            "type": "object",
+            "properties": {
+                "event": {
+                    "enum": [
+                        "cli.suite.edit",
+                        "cli.suite.edit.begin",
+                        "cli.suite.edit.end",
+                    ]
+                },
+                "event_payload": {
+                    "$ref": "#/definitions/cli_suite_expectation_suite_payload"
+                },
+            },
+        },
+        {
+            "type": "object",
+            "properties": {
+                "event": {
+                    "enum": [
+                        "cli.checkpoint.delete",
+                        "cli.checkpoint.delete.begin",
+                        "cli.checkpoint.delete.end",
+                        "cli.checkpoint.list",
+                        "cli.checkpoint.list.begin",
+                        "cli.checkpoint.list.end",
+                        "cli.checkpoint.new",
+                        "cli.checkpoint.new.begin",
+                        "cli.checkpoint.new.end",
+                        "cli.checkpoint.run",
+                        "cli.checkpoint.run.begin",
+                        "cli.checkpoint.run.end",
+                        "cli.checkpoint.script",
+                        "cli.checkpoint.script.begin",
+                        "cli.checkpoint.script.end",
+                        "cli.datasource.list",
+                        "cli.datasource.list.begin",
+                        "cli.datasource.list.end",
+                        "cli.datasource.new",
+                        "cli.datasource.new.begin",
+                        "cli.datasource.new.end",
+                        "cli.datasource.delete",
+                        "cli.datasource.delete.begin",
+                        "cli.datasource.delete.end",
+                        "cli.datasource.profile",
+                        "cli.docs.build",
+                        "cli.docs.build.begin",
+                        "cli.docs.build.end",
+                        "cli.docs.clean",
+                        "cli.docs.clean.begin",
+                        "cli.docs.clean.end",
+                        "cli.docs.list",
+                        "cli.docs.list.begin",
+                        "cli.docs.list.end",
+                        "cli.init.create",
+                        "cli.project.check_config",
+                        "cli.project.upgrade.begin",
+                        "cli.project.upgrade.end",
+                        "cli.store.list",
+                        "cli.store.list.begin",
+                        "cli.store.list.end",
+                        "cli.suite.delete",
+                        "cli.suite.delete.begin",
+                        "cli.suite.delete.end",
+                        "cli.suite.demo",
+                        "cli.suite.demo.begin",
+                        "cli.suite.demo.end",
+                        "cli.suite.list",
+                        "cli.suite.list.begin",
+                        "cli.suite.list.end",
+                        "cli.suite.new",
+                        "cli.suite.new.begin",
+                        "cli.suite.new.end",
+                        "cli.suite.scaffold",
+                        "cli.validation_operator.list",
+                        "cli.validation_operator.run",
+                    ],
+                },
+                "event_payload": {"$ref": "#/definitions/cli_payload"},
+            },
+        },
     ],
     "required": [
         "version",
