@@ -2,7 +2,7 @@
 
 import logging
 import warnings
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional
 
 import numpy as np
 import pandas as pd
@@ -20,30 +20,6 @@ except ImportError:
     WithinGroup = None
 
 
-SCHEMAS = {
-    "api_np": {"NegativeInfinity": -np.inf, "PositiveInfinity": np.inf,},
-    "api_cast": {"NegativeInfinity": -float("inf"), "PositiveInfinity": float("inf"),},
-    "mysql": {"NegativeInfinity": -1.79e308, "PositiveInfinity": 1.79e308,},
-    "mssql": {"NegativeInfinity": -1.79e308, "PositiveInfinity": 1.79e308,},
-}
-
-
-def get_sql_dialect_floating_point_infinity_value(
-    schema: str, negative: bool = False
-) -> float:
-    res: Union[Dict, None] = SCHEMAS.get(schema)
-    if res is None:
-        if negative:
-            return -np.inf
-        else:
-            return np.inf
-    else:
-        if negative:
-            return res["NegativeInfinity"]
-        else:
-            return res["PositiveInfinity"]
-
-
 def is_valid_partition_object(partition_object):
     """Tests whether a given object is a valid continuous or categorical partition object.
     :param partition_object: The partition_object to evaluate
@@ -383,7 +359,7 @@ def infer_distribution_parameters(data, distribution, params=None):
     #    if 'lambda' in params.keys():
     # Lambda is optional
     #        params['scale'] = 1 / params['lambda']
-    elif distribution is not "norm":
+    elif distribution != "norm":
         raise AttributeError(
             "Unsupported distribution type. Please refer to Great Expectations Documentation"
         )
@@ -615,7 +591,8 @@ def get_approximate_percentile_disc_sql(selects: List, sql_engine_dialect: Any)
 
 
 def check_sql_engine_dialect(
-    actual_sql_engine_dialect: Any, candidate_sql_engine_dialect: Any,
+    actual_sql_engine_dialect: Any,
+    candidate_sql_engine_dialect: Any,
 ) -> bool:
     try:
         # noinspection PyTypeChecker
