@@ -1,15 +1,19 @@
 import logging
 import os
 from collections import OrderedDict
+from typing import List
 
-from dateutil.parser import ParserError, parse
+from dateutil.parser import parse
 
-from great_expectations.core import RunIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
 from great_expectations.render.util import num_to_str
 
-from ...core.id_dict import BatchKwargs
+from ...core.expectation_validation_result import ExpectationSuiteValidationResult
+from ...core.run_identifier import RunIdentifier
+from ...validation_operators.types.validation_operator_result import (
+    ValidationOperatorResult,
+)
 from ..types import (
     CollapseContent,
     RenderedDocumentContent,
@@ -26,7 +30,13 @@ logger = logging.getLogger(__name__)
 
 
 class ValidationResultsPageRenderer(Renderer):
-    def __init__(self, column_section_renderer=None):
+    def __init__(self, column_section_renderer=None, run_info_at_end: bool = False):
+        """
+        Args:
+            column_section_renderer:
+            run_info_at_end: Move the run info (Info, Batch Markers, Batch Kwargs) to the end
+                of the rendered output rather than after Statistics.
+        """
         super().__init__()
         if column_section_renderer is None:
             column_section_renderer = {
@@ -46,13 +56,36 @@ class ValidationResultsPageRenderer(Renderer):
                 package_name=None,
                 class_name=column_section_renderer["class_name"],
             )
+        self.run_info_at_end = run_info_at_end
 
-    def render(self, validation_results):
+    def render_validation_operator_result(
+        self, validation_operator_result: ValidationOperatorResult
+    ) -> List[RenderedDocumentContent]:
+        """
+        Render a ValidationOperatorResult which can have multiple ExpectationSuiteValidationResult
+
+        Args:
+            validation_operator_result: ValidationOperatorResult
+
+        Returns:
+            List[RenderedDocumentContent]
+        """
+        return [
+            self.render(validation_result)
+            for validation_result in validation_operator_result.list_validation_results()
+        ]
+
+    # TODO: deprecate dual batch api support in 0.14
+    def render(
+        self,
+        validation_results: ExpectationSuiteValidationResult,
+        evaluation_parameters=None,
+    ):
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
-                run_time = parse(run_id).strftime("%Y%m%dT%H%M%S.%fZ")
-            except (ParserError, TypeError):
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
                 run_time = "__none__"
             run_name = run_id
         elif isinstance(run_id, dict):
@@ -60,16 +93,23 @@ class ValidationResultsPageRenderer(Renderer):
             run_time = run_id.get("run_time") or "__none__"
         elif isinstance(run_id, RunIdentifier):
             run_name = run_id.run_name or "__none__"
-            run_time = run_id.run_time.strftime("%Y%m%dT%H%M%S.%fZ")
-        batch_id = BatchKwargs(validation_results.meta["batch_kwargs"]).to_id()
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
-        batch_kwargs = validation_results.meta.get("batch_kwargs")
+        batch_kwargs = (
+            validation_results.meta.get("batch_kwargs", {})
+            or validation_results.meta.get("batch_spec", {})
+            or {}
+        )
 
         # add datasource key to batch_kwargs if missing
-        if "datasource" not in validation_results.meta.get("batch_kwargs", {}):
+        if "datasource" not in batch_kwargs and "datasource" not in batch_kwargs:
             # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
             if len(expectation_suite_name.split(".")) == 4:
-                batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
+                if "batch_kwargs" in validation_results.meta:
+                    batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
+                else:
+                    batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
 
         # Group EVRs by column
         columns = {}
@@ -84,7 +124,6 @@ class ValidationResultsPageRenderer(Renderer):
             columns[column].append(evr)
 
         ordered_columns = Renderer._get_column_list_from_evrs(validation_results)
-
         overview_content_blocks = [
             self._render_validation_header(validation_results),
             self._render_validation_statistics(validation_results=validation_results),
@@ -94,7 +133,7 @@ class ValidationResultsPageRenderer(Renderer):
             self._render_validation_info(validation_results=validation_results)
         ]
 
-        if validation_results["meta"].get("batch_markers"):
+        if validation_results.meta.get("batch_markers"):
             collapse_content_blocks.append(
                 self._render_nested_table_from_dict(
                     input_dict=validation_results["meta"].get("batch_markers"),
@@ -102,22 +141,38 @@ class ValidationResultsPageRenderer(Renderer):
                 )
             )
 
-        if validation_results["meta"].get("batch_kwargs"):
+        if validation_results.meta.get("batch_kwargs"):
             collapse_content_blocks.append(
                 self._render_nested_table_from_dict(
-                    input_dict=validation_results["meta"].get("batch_kwargs"),
+                    input_dict=validation_results.meta.get("batch_kwargs"),
                     header="Batch Kwargs",
                 )
             )
 
-        if validation_results["meta"].get("batch_parameters"):
+        if validation_results.meta.get("batch_parameters"):
             collapse_content_blocks.append(
                 self._render_nested_table_from_dict(
-                    input_dict=validation_results["meta"].get("batch_parameters"),
+                    input_dict=validation_results.meta.get("batch_parameters"),
                     header="Batch Parameters",
                 )
             )
 
+        if validation_results.meta.get("batch_spec"):
+            collapse_content_blocks.append(
+                self._render_nested_table_from_dict(
+                    input_dict=validation_results.meta.get("batch_spec"),
+                    header="Batch Spec",
+                )
+            )
+
+        if validation_results.meta.get("batch_request"):
+            collapse_content_blocks.append(
+                self._render_nested_table_from_dict(
+                    input_dict=validation_results.meta.get("batch_request"),
+                    header="Batch Definition",
+                )
+            )
+
         collapse_content_block = CollapseContent(
             **{
                 "collapse_toggle_link": "Show more info...",
@@ -129,7 +184,8 @@ class ValidationResultsPageRenderer(Renderer):
             }
         )
 
-        overview_content_blocks.append(collapse_content_block)
+        if not self.run_info_at_end:
+            overview_content_blocks.append(collapse_content_block)
 
         sections = [
             RenderedSectionContent(
@@ -143,26 +199,60 @@ class ValidationResultsPageRenderer(Renderer):
         if "Table-Level Expectations" in columns:
             sections += [
                 self._column_section_renderer.render(
-                    validation_results=columns["Table-Level Expectations"]
+                    validation_results=columns["Table-Level Expectations"],
+                    evaluation_parameters=validation_results.evaluation_parameters,
                 )
             ]
 
         sections += [
-            self._column_section_renderer.render(validation_results=columns[column],)
+            self._column_section_renderer.render(
+                validation_results=columns[column],
+                evaluation_parameters=validation_results.evaluation_parameters,
+            )
             for column in ordered_columns
         ]
+        if self.run_info_at_end:
+            sections += [
+                RenderedSectionContent(
+                    **{
+                        "section_name": "Run Info",
+                        "content_blocks": collapse_content_blocks,
+                    }
+                )
+            ]
+
+        data_asset_name = batch_kwargs.get("data_asset_name")
+        # Determine whether we have a custom run_name
+        try:
+            run_name_as_time = parse(run_name)
+        except ValueError:
+            run_name_as_time = None
+        try:
+            run_time_datetime = parse(run_time)
+        except ValueError:
+            run_time_datetime = None
+
+        include_run_name: bool = False
+        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+            include_run_name = True
+
+        page_title = "Validations / " + str(expectation_suite_name)
+        if data_asset_name:
+            page_title += " / " + str(data_asset_name)
+        if include_run_name:
+            page_title += " / " + str(run_name)
+        page_title += " / " + str(run_time)
 
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ValidationResultsPageRenderer",
-                "page_title": expectation_suite_name
-                + " / "
-                + run_name
-                + " / "
-                + run_time
-                + " / "
-                + batch_id,
-                "batch_kwargs": batch_kwargs,
+                "page_title": page_title,
+                "batch_kwargs": batch_kwargs
+                if "batch_kwargs" in validation_results.meta
+                else None,
+                "batch_spec": batch_kwargs
+                if "batch_spec" in validation_results.meta
+                else None,
                 "expectation_suite_name": expectation_suite_name,
                 "sections": sections,
                 "utm_medium": "validation-results-page",
@@ -176,17 +266,30 @@ class ValidationResultsPageRenderer(Renderer):
         expectation_suite_path_components = (
             [".." for _ in range(len(expectation_suite_name.split(".")) + 3)]
             + ["expectations"]
-            + expectation_suite_name.split(".")
+            + str(expectation_suite_name).split(".")
         )
         expectation_suite_path = (
             os.path.join(*expectation_suite_path_components) + ".html"
         )
+        # TODO: deprecate dual batch api support in 0.14
+        batch_kwargs = (
+            validation_results.meta.get("batch_kwargs", {})
+            or validation_results.meta.get("batch_spec", {})
+            or {}
+        )
+        data_asset_name = batch_kwargs.get("data_asset_name")
+
         if success:
-            success = '<i class="fas fa-check-circle text-success" aria-hidden="true"></i> Succeeded'
-        else:
-            success = (
-                '<i class="fas fa-times text-danger" aria-hidden="true"></i> Failed'
+            success = "Succeeded"
+            html_success_icon = (
+                '<i class="fas fa-check-circle text-success" aria-hidden="true"></i>'
             )
+        else:
+            success = "Failed"
+            html_success_icon = (
+                '<i class="fas fa-times text-danger" aria-hidden="true"></i>'
+            )
+
         return RenderedHeaderContent(
             **{
                 "content_block_type": "header",
@@ -204,12 +307,15 @@ class ValidationResultsPageRenderer(Renderer):
                     **{
                         "content_block_type": "string_template",
                         "string_template": {
-                            "template": "${suite_title} ${expectation_suite_name}\n${status_title} ${success}",
+                            "template": "${suite_title} ${expectation_suite_name}\n ${data_asset} ${data_asset_name}\n ${status_title} ${html_success_icon} ${success}",
                             "params": {
                                 "suite_title": "Expectation Suite:",
+                                "data_asset": "Data asset:",
+                                "data_asset_name": data_asset_name,
                                 "status_title": "Status:",
                                 "expectation_suite_name": expectation_suite_name,
                                 "success": success,
+                                "html_success_icon": html_success_icon,
                             },
                             "styling": {
                                 "params": {
@@ -237,8 +343,8 @@ class ValidationResultsPageRenderer(Renderer):
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
-                run_time = parse(run_id).strftime("%Y%m%dT%H%M%S.%fZ")
-            except (ParserError, TypeError):
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
                 run_time = "__none__"
             run_name = run_id
         elif isinstance(run_id, dict):
@@ -246,8 +352,11 @@ class ValidationResultsPageRenderer(Renderer):
             run_time = run_id.get("run_time") or "__none__"
         elif isinstance(run_id, RunIdentifier):
             run_name = run_id.run_name or "__none__"
-            run_time = run_id.run_time.strftime("%Y%m%dT%H%M%S.%fZ")
-        ge_version = validation_results.meta["great_expectations.__version__"]
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+        # TODO: Deprecate "great_expectations.__version__"
+        ge_version = validation_results.meta.get(
+            "great_expectations_version"
+        ) or validation_results.meta.get("great_expectations.__version__")
 
         return RenderedTableContent(
             **{
@@ -283,7 +392,6 @@ class ValidationResultsPageRenderer(Renderer):
     @classmethod
     def _render_nested_table_from_dict(cls, input_dict, header=None, sub_table=False):
         table_rows = []
-
         for kwarg, value in input_dict.items():
             if not isinstance(value, (dict, OrderedDict)):
                 table_row = [
@@ -297,7 +405,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": ["pr-3"],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": ["pr-3"],
+                                }
+                            },
                         }
                     ),
                     RenderedStringTemplateContent(
@@ -310,7 +422,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": [],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": [],
+                                }
+                            },
                         }
                     ),
                 ]
@@ -326,7 +442,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": ["pr-3"],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": ["pr-3"],
+                                }
+                            },
                         }
                     ),
                     cls._render_nested_table_from_dict(value, sub_table=True),
@@ -376,7 +496,7 @@ class ValidationResultsPageRenderer(Renderer):
 
     @classmethod
     def _render_validation_statistics(cls, validation_results):
-        statistics = validation_results["statistics"]
+        statistics = validation_results.statistics
         statistics_dict = OrderedDict(
             [
                 ("evaluated_expectations", "Evaluated Expectations"),
@@ -484,7 +604,7 @@ class ExpectationSuitePageRenderer(Renderer):
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ExpectationSuitePageRenderer",
-                "page_title": expectation_suite_name,
+                "page_title": "Expectations / " + str(expectation_suite_name),
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "expectation-suite-page",
                 "sections": sections,
@@ -536,7 +656,10 @@ class ExpectationSuitePageRenderer(Renderer):
     @classmethod
     def _render_expectation_suite_info(cls, expectations):
         expectation_suite_name = expectations.expectation_suite_name
-        ge_version = expectations.meta["great_expectations.__version__"]
+        # TODO: Deprecate "great_expectations.__version__"
+        ge_version = expectations.meta.get(
+            "great_expectations_version"
+        ) or expectations.meta.get("great_expectations.__version__")
 
         return RenderedTableContent(
             **{
@@ -586,7 +709,10 @@ class ExpectationSuitePageRenderer(Renderer):
             # "This Expectation suite was first generated by {BasicDatasetProfiler} on {date}, using version {xxx} of Great Expectations.",
             # "{name}, {name}, and {name} have also contributed additions and revisions.",
             "This Expectation suite currently contains %d total Expectations across %d columns."
-            % (total_expectations, total_columns,),
+            % (
+                total_expectations,
+                total_columns,
+            ),
         ]
 
         if "notes" in expectations.meta:
@@ -678,7 +804,7 @@ class ProfilingResultsPageRenderer(Renderer):
             column_section_renderer = {
                 "class_name": "ProfilingResultsColumnSectionRenderer"
             }
-        module_name = "great_expectations.render.renderer.other_section_renderer"
+        module_name = "great_expectations.render.renderer.profiling_results_overview_section_renderer"
         self._overview_section_renderer = instantiate_class_from_config(
             config=overview_section_renderer,
             runtime_environment={},
@@ -711,8 +837,8 @@ class ProfilingResultsPageRenderer(Renderer):
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
-                run_time = parse(run_id).strftime("%Y%m%dT%H%M%S.%fZ")
-            except (ParserError, TypeError):
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
                 run_time = "__none__"
             run_name = run_id
         elif isinstance(run_id, dict):
@@ -720,16 +846,21 @@ class ProfilingResultsPageRenderer(Renderer):
             run_time = run_id.get("run_time") or "__none__"
         elif isinstance(run_id, RunIdentifier):
             run_name = run_id.run_name or "__none__"
-            run_time = run_id.run_time.strftime("%Y%m%dT%H%M%S.%fZ")
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
 
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
-        batch_kwargs = validation_results.meta.get("batch_kwargs")
+        batch_kwargs = validation_results.meta.get(
+            "batch_kwargs", {}
+        ) or validation_results.meta.get("batch_spec", {})
 
         # add datasource key to batch_kwargs if missing
-        if "datasource" not in validation_results.meta.get("batch_kwargs", {}):
+        if "datasource" not in batch_kwargs and "datasource" not in batch_kwargs:
             # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
             if len(expectation_suite_name.split(".")) == 4:
-                batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
+                if "batch_kwargs" in validation_results.meta:
+                    batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
+                else:
+                    batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
 
         # Group EVRs by column
         # TODO: When we implement a ValidationResultSuite class, this method will move there.
@@ -740,18 +871,40 @@ class ProfilingResultsPageRenderer(Renderer):
             validation_results
         )
 
+        data_asset_name = batch_kwargs.get("data_asset_name")
+        # Determine whether we have a custom run_name
+        try:
+            run_name_as_time = parse(run_name)
+        except ValueError:
+            run_name_as_time = None
+        try:
+            run_time_datetime = parse(run_time)
+        except ValueError:
+            run_time_datetime = None
+
+        include_run_name: bool = False
+        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+            include_run_name = True
+
+        page_title = "Profiling Results / " + str(expectation_suite_name)
+        if data_asset_name:
+            page_title += " / " + str(data_asset_name)
+        if include_run_name:
+            page_title += " / " + str(run_name)
+        page_title += " / " + str(run_time)
+
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ProfilingResultsPageRenderer",
-                "page_title": run_time
-                + "-"
-                + run_name
-                + "-"
-                + expectation_suite_name
-                + "-ProfilingResults",
+                "page_title": page_title,
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "profiling-results-page",
-                "batch_kwargs": batch_kwargs,
+                "batch_kwargs": batch_kwargs
+                if "batch_kwargs" in validation_results.meta
+                else None,
+                "batch_spec": batch_kwargs
+                if "batch_spec" in validation_results.meta
+                else None,
                 "sections": [
                     self._overview_section_renderer.render(
                         validation_results, section_name="Overview"
