@@ -13,7 +13,12 @@ from tests.cli.utils import assert_no_logging_messages_or_tracebacks
 
 
 def _library_not_loaded_test(
-    tmp_path_factory, cli_input, library_name, library_import_name, my_caplog
+    tmp_path_factory,
+    cli_input,
+    library_name,
+    library_import_name,
+    my_caplog,
+    monkeypatch,
 ):
     """
     This test requires that a library is NOT installed. It tests that:
@@ -22,15 +27,13 @@ def _library_not_loaded_test(
     - the config yml contains an empty dict in its datasource entry
     """
     basedir = tmp_path_factory.mktemp("test_cli_init_diff")
-    basedir = str(basedir)
-    os.chdir(basedir)
-
     runner = CliRunner(mix_stderr=False)
+    monkeypatch.chdir(basedir)
     result = runner.invoke(
-        cli, ["init", "--no-view"], input=cli_input, catch_exceptions=False
+        cli, ["--v3-api", "init", "--no-view"], input=cli_input, catch_exceptions=False
     )
     stdout = result.output
-
+    print(stdout)
     assert "Always know what to expect from your data" in stdout
     assert "What data would you like Great Expectations to connect to" in stdout
     assert "Which database backend are you using" in stdout
@@ -63,7 +66,7 @@ but the package `{library_name}` containing this library is not installed.
     config_path = os.path.join(basedir, "great_expectations/great_expectations.yml")
     assert os.path.isfile(config_path)
 
-    config = yaml.load(open(config_path, "r"))
+    config = yaml.load(open(config_path))
     assert config["datasources"] == dict()
 
     obs_tree = gen_directory_tree_str(os.path.join(basedir, "great_expectations"))
@@ -75,6 +78,7 @@ great_expectations/
     great_expectations.yml
     checkpoints/
     expectations/
+        .ge_store_backend_id
     notebooks/
         pandas/
             validation_playground.ipynb
@@ -92,17 +96,23 @@ great_expectations/
         config_variables.yml
         data_docs/
         validations/
+            .ge_store_backend_id
 """
     )
 
     assert_no_logging_messages_or_tracebacks(my_caplog, result)
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="sqlalchemy"),
     reason="requires sqlalchemy to NOT be installed",
 )
-def test_init_install_sqlalchemy(caplog, tmp_path_factory):
+def test_init_install_sqlalchemy(caplog, tmp_path_factory, monkeypatch):
     """WARNING: THIS TEST IS AWFUL AND WE HATE IT."""
     # This test is as much about changing the entire test environment with side effects as it is about actually testing
     # the observed behavior.
@@ -112,12 +122,11 @@ def test_init_install_sqlalchemy(caplog, tmp_path_factory):
     cli_input = "\n\n2\nn\n"
 
     basedir = tmp_path_factory.mktemp("test_cli_init_diff")
-    basedir = str(basedir)
-    os.chdir(basedir)
 
     runner = CliRunner(mix_stderr=False)
+    monkeypatch.chdir(basedir)
     result = runner.invoke(
-        cli, ["init", "--no-view"], input=cli_input, catch_exceptions=False
+        cli, ["--v3-api", "init", "--no-view"], input=cli_input, catch_exceptions=False
     )
     stdout = result.output
 
@@ -134,62 +143,106 @@ but the package `{library_name}` containing this library is not installed.
     _ = execute_shell_command_with_progress_polling("pip install sqlalchemy")
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="pymysql"),
     reason="requires pymysql to NOT be installed",
 )
 def test_cli_init_db_mysql_without_library_installed_instructs_user(
-    caplog, tmp_path_factory
+    caplog, tmp_path_factory, monkeypatch
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n1\nmy_db\nn\n", "pymysql", "pymysql", caplog
+        tmp_path_factory,
+        "\n\n2\n1\nmy_db\nn\n",
+        "pymysql",
+        "pymysql",
+        caplog,
+        monkeypatch,
     )
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="pyodbc"),
     reason="requires pyodbc to NOT be installed",
 )
 def test_cli_init_db_mssql_without_library_installed_instructs_user(
-    caplog, tmp_path_factory
+    caplog, tmp_path_factory, monkeypatch
 ):
     # TODO: Update to reflect the CLI flow sequence (once it has been implemented) and re-enable.
-    # _library_not_loaded_test(
-    #     tmp_path_factory, "\n\n2\n6\nmy_db\nwrong_ms_sql_server_library\nn\n", "pyodbc", "pyodbc", caplog
-    # )
-    return True
+    _library_not_loaded_test(
+        tmp_path_factory,
+        "\n\n2\n6\nmy_db\nwrong_ms_sql_server_library\nn\n",
+        "pyodbc",
+        "pyodbc",
+        caplog,
+        monkeypatch,
+    )
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="psycopg2"),
     reason="requires psycopg2 to NOT be installed",
 )
 def test_cli_init_db_postgres_without_library_installed_instructs_user(
-    caplog, tmp_path_factory,
+    caplog, tmp_path_factory, monkeypatch
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n2\nmy_db\nn\n", "psycopg2-binary", "psycopg2", caplog
+        tmp_path_factory,
+        "\n\n2\n2\nmy_db\nn\n",
+        "psycopg2-binary",
+        "psycopg2",
+        caplog,
+        monkeypatch,
     )
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="psycopg2"),
     reason="requires psycopg2 to NOT be installed",
 )
 def test_cli_init_db_redshift_without_library_installed_instructs_user(
-    caplog, tmp_path_factory,
+    caplog, tmp_path_factory, monkeypatch
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n3\nmy_db\nn\n", "psycopg2-binary", "psycopg2", caplog
+        tmp_path_factory,
+        "\n\n2\n3\nmy_db\nn\n",
+        "psycopg2-binary",
+        "psycopg2",
+        caplog,
+        monkeypatch,
     )
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="snowflake.sqlalchemy"),
     reason="requires snowflake-sqlalchemy to NOT be installed",
 )
 def test_cli_init_db_snowflake_without_library_installed_instructs_user(
-    caplog, tmp_path_factory,
+    caplog, tmp_path_factory, monkeypatch
 ):
     _library_not_loaded_test(
         tmp_path_factory,
@@ -197,26 +250,33 @@ def test_cli_init_db_snowflake_without_library_installed_instructs_user(
         "snowflake-sqlalchemy",
         "snowflake.sqlalchemy.snowdialect",
         caplog,
+        monkeypatch,
     )
 
 
+@pytest.mark.xfail(
+    reason="This command is not yet implemented for the modern API",
+    run=True,
+    strict=True,
+)
 @pytest.mark.skipif(
     is_library_loadable(library_name="pyspark"),
     reason="requires pyspark to NOT be installed",
 )
 def test_cli_init_spark_without_library_installed_instructs_user(
-    caplog, tmp_path_factory
+    caplog, tmp_path_factory, monkeypatch
 ):
     basedir = tmp_path_factory.mktemp("test_cli_init_diff")
-    basedir = str(basedir)
-    os.chdir(basedir)
 
     runner = CliRunner(mix_stderr=False)
+    monkeypatch.chdir(basedir)
     result = runner.invoke(
-        cli, ["init", "--no-view"], input="\n\n1\n2\nn\n", catch_exceptions=False
+        cli,
+        ["--v3-api", "init", "--no-view"],
+        input="\n\n1\n2\nn\n",
+        catch_exceptions=False,
     )
     stdout = result.output
-
     assert "Always know what to expect from your data" in stdout
     assert "What data would you like Great Expectations to connect to" in stdout
     assert "What are you processing your files with" in stdout
@@ -245,7 +305,7 @@ but the package `pyspark` containing this library is not installed.
     config_path = os.path.join(basedir, "great_expectations/great_expectations.yml")
     assert os.path.isfile(config_path)
 
-    config = yaml.load(open(config_path, "r"))
+    config = yaml.load(open(config_path))
     assert config["datasources"] == dict()
 
     obs_tree = gen_directory_tree_str(os.path.join(basedir, "great_expectations"))
@@ -257,6 +317,7 @@ great_expectations/
     great_expectations.yml
     checkpoints/
     expectations/
+        .ge_store_backend_id
     notebooks/
         pandas/
             validation_playground.ipynb
@@ -274,6 +335,7 @@ great_expectations/
         config_variables.yml
         data_docs/
         validations/
+            .ge_store_backend_id
 """
     )
 
