@@ -5,11 +5,10 @@ import pandas as pd
 import pytest
 
 import great_expectations as ge
-from great_expectations.core import (
-    ExpectationConfiguration,
-    ExpectationSuite,
+from great_expectations.core import ExpectationConfiguration, expectationSuiteSchema
+from great_expectations.core.expectation_suite import ExpectationSuite
+from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
-    expectationSuiteSchema,
 )
 from great_expectations.exceptions import InvalidExpectationConfigurationError
 
@@ -19,7 +18,11 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         tmp_path_factory.mktemp("test_get_and_save_expectation_config")
     )
     df = ge.dataset.PandasDataset(
-        {"x": [1, 2, 4], "y": [1, 2, 5], "z": ["hello", "jello", "mello"],}
+        {
+            "x": [1, 2, 4],
+            "y": [1, 2, 5],
+            "z": ["hello", "jello", "mello"],
+        }
     )
 
     df.expect_column_values_to_be_in_set("x", [1, 2, 4])
@@ -27,6 +30,8 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         "y", [1, 2, 4], catch_exceptions=True, include_config=True
     )
     df.expect_column_values_to_match_regex("z", "ello")
+    df.expect_compound_columns_to_be_unique(column_list=["x", "y"])
+    df.expect_compound_columns_to_be_unique(column_list=["y", "z"])
 
     ### First test set ###
 
@@ -40,6 +45,14 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
                 expectation_type="expect_column_values_to_match_regex",
                 kwargs={"column": "z", "regex": "ello"},
             ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["x", "y"]},
+            ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["y", "z"]},
+            ),
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
@@ -69,6 +82,14 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
                 expectation_type="expect_column_values_to_match_regex",
                 kwargs={"column": "z", "regex": "ello"},
             ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["x", "y"]},
+            ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["y", "z"]},
+            ),
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
@@ -99,6 +120,14 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
                 expectation_type="expect_column_values_to_match_regex",
                 kwargs={"column": "z", "regex": "ello", "result_format": "BASIC"},
             ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["x", "y"], "result_format": "BASIC"},
+            ),
+            ExpectationConfiguration(
+                expectation_type="expect_compound_columns_to_be_unique",
+                kwargs={"column_list": ["y", "z"], "result_format": "BASIC"},
+            ),
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
@@ -109,7 +138,6 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         discard_include_config_kwargs=False,
         discard_catch_exceptions_kwargs=False,
     )
-
     df.save_expectation_suite(
         directory_name + "/temp3.json",
         discard_result_format_kwargs=False,
@@ -123,7 +151,11 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
 
 def test_expectation_meta():
     df = ge.dataset.PandasDataset(
-        {"x": [1, 2, 4], "y": [1, 2, 5], "z": ["hello", "jello", "mello"],}
+        {
+            "x": [1, 2, 4],
+            "y": [1, 2, 5],
+            "z": ["hello", "jello", "mello"],
+        }
     )
     result = df.expect_column_median_to_be_between(
         "x", 2, 2, meta={"notes": "This expectation is for lolz."}
@@ -147,7 +179,11 @@ def test_expectation_meta():
 
 def test_set_default_expectation_argument():
     df = ge.dataset.PandasDataset(
-        {"x": [1, 2, 4], "y": [1, 2, 5], "z": ["hello", "jello", "mello"],}
+        {
+            "x": [1, 2, 4],
+            "y": [1, 2, 5],
+            "z": ["hello", "jello", "mello"],
+        }
     )
 
     assert {
@@ -166,7 +202,12 @@ def test_set_default_expectation_argument():
 
 
 def test_test_column_map_expectation_function():
-    asset = ge.dataset.PandasDataset({"x": [1, 3, 5, 7, 9], "y": [1, 2, None, 7, 9],})
+    asset = ge.dataset.PandasDataset(
+        {
+            "x": [1, 3, 5, 7, 9],
+            "y": [1, 2, None, 7, 9],
+        }
+    )
 
     def is_odd(
         self,
@@ -202,17 +243,25 @@ def test_test_column_map_expectation_function():
         is_odd, column="y", result_format="BOOLEAN_ONLY", include_config=False
     ) == ExpectationValidationResult(success=False)
 
-    assert asset.test_column_map_expectation_function(
-        is_odd,
-        column="y",
-        result_format="BOOLEAN_ONLY",
-        mostly=0.7,
-        include_config=False,
-    ) == ExpectationValidationResult(success=True)
+    assert (
+        asset.test_column_map_expectation_function(
+            is_odd,
+            column="y",
+            result_format="BOOLEAN_ONLY",
+            mostly=0.7,
+            include_config=False,
+        )
+        == ExpectationValidationResult(success=True)
+    )
 
 
 def test_test_column_aggregate_expectation_function():
-    asset = ge.dataset.PandasDataset({"x": [1, 3, 5, 7, 9], "y": [1, 2, None, 7, 9],})
+    asset = ge.dataset.PandasDataset(
+        {
+            "x": [1, 3, 5, 7, 9],
+            "y": [1, 2, None, 7, 9],
+        }
+    )
 
     def expect_second_value_to_be(
         self,
@@ -225,7 +274,9 @@ def test_test_column_aggregate_expectation_function():
     ):
         return {
             "success": self[column].iloc[1] == value,
-            "result": {"observed_value": self[column].iloc[1],},
+            "result": {
+                "observed_value": self[column].iloc[1],
+            },
         }
 
     assert asset.test_column_aggregate_expectation_function(
@@ -252,54 +303,35 @@ def test_test_column_aggregate_expectation_function():
         success=True,
     )
 
-    assert asset.test_column_aggregate_expectation_function(
-        expect_second_value_to_be,
-        "y",
-        value=3,
-        result_format="BOOLEAN_ONLY",
-        include_config=False,
-    ) == ExpectationValidationResult(success=False)
-
-    assert asset.test_column_aggregate_expectation_function(
-        expect_second_value_to_be,
-        "y",
-        2,
-        result_format="BOOLEAN_ONLY",
-        include_config=False,
-    ) == ExpectationValidationResult(success=True)
-
-
-def test_meta_version_warning():
-    asset = ge.data_asset.DataAsset()
-
-    with pytest.warns(UserWarning) as w:
-        suite = ExpectationSuite(expectations=[], expectation_suite_name="test")
-        # mangle the metadata
-        suite.meta = {"foo": "bar"}
-        out = asset.validate(expectation_suite=suite)
     assert (
-        w[0].message.args[0]
-        == "WARNING: No great_expectations version found in configuration object."
+        asset.test_column_aggregate_expectation_function(
+            expect_second_value_to_be,
+            "y",
+            value=3,
+            result_format="BOOLEAN_ONLY",
+            include_config=False,
+        )
+        == ExpectationValidationResult(success=False)
     )
 
-    with pytest.warns(UserWarning) as w:
-        suite = ExpectationSuite(
-            expectations=[],
-            expectation_suite_name="test",
-            meta={"great_expectations_version": "0.0.0"},
-        )
-        # mangle the metadata
-        suite.meta = {"great_expectations_version": "0.0.0"}
-        out = asset.validate(expectation_suite=suite)
     assert (
-        w[0].message.args[0]
-        == "WARNING: This configuration object was built using version 0.0.0 of great_expectations, but is currently "
-        "being validated by version %s." % ge.__version__
+        asset.test_column_aggregate_expectation_function(
+            expect_second_value_to_be,
+            "y",
+            2,
+            result_format="BOOLEAN_ONLY",
+            include_config=False,
+        )
+        == ExpectationValidationResult(success=True)
     )
 
 
 def test_format_map_output():
-    df = ge.dataset.PandasDataset({"x": list("abcdefghijklmnopqrstuvwxyz"),})
+    df = ge.dataset.PandasDataset(
+        {
+            "x": list("abcdefghijklmnopqrstuvwxyz"),
+        }
+    )
 
     ### Normal Test ###
 
@@ -312,15 +344,18 @@ def test_format_map_output():
     unexpected_list = []
     unexpected_index_list = []
 
-    assert df._format_map_output(
-        "BOOLEAN_ONLY",
-        success,
-        element_count,
-        nonnull_count,
-        len(unexpected_list),
-        unexpected_list,
-        unexpected_index_list,
-    ) == {"success": True}
+    assert (
+        df._format_map_output(
+            "BOOLEAN_ONLY",
+            success,
+            element_count,
+            nonnull_count,
+            len(unexpected_list),
+            unexpected_list,
+            unexpected_index_list,
+        )
+        == {"success": True}
+    )
 
     assert df._format_map_output(
         "BASIC",
@@ -339,6 +374,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": 0.0,
+            "unexpected_percent_total": 0.0,
             "unexpected_percent_nonmissing": 0.0,
         },
     }
@@ -360,6 +396,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": 0.0,
+            "unexpected_percent_total": 0.0,
             "unexpected_percent_nonmissing": 0.0,
             "partial_unexpected_index_list": [],
             "partial_unexpected_counts": [],
@@ -383,6 +420,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": 0.0,
+            "unexpected_percent_total": 0.0,
             "unexpected_percent_nonmissing": 0.0,
             "partial_unexpected_index_list": [],
             "partial_unexpected_counts": [],
@@ -402,15 +440,18 @@ def test_format_map_output():
     unexpected_list = []
     unexpected_index_list = []
 
-    assert df._format_map_output(
-        "BOOLEAN_ONLY",
-        success,
-        element_count,
-        nonnull_count,
-        len(unexpected_list),
-        unexpected_list,
-        unexpected_index_list,
-    ) == {"success": True}
+    assert (
+        df._format_map_output(
+            "BOOLEAN_ONLY",
+            success,
+            element_count,
+            nonnull_count,
+            len(unexpected_list),
+            unexpected_list,
+            unexpected_index_list,
+        )
+        == {"success": True}
+    )
 
     assert df._format_map_output(
         "BASIC",
@@ -428,7 +469,8 @@ def test_format_map_output():
             "missing_percent": 100,
             "partial_unexpected_list": [],
             "unexpected_count": 0,
-            "unexpected_percent": 0.0,
+            "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
         },
     }
@@ -449,7 +491,8 @@ def test_format_map_output():
             "missing_percent": 100,
             "partial_unexpected_list": [],
             "unexpected_count": 0,
-            "unexpected_percent": 0.0,
+            "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
             "partial_unexpected_index_list": [],
             "partial_unexpected_counts": [],
@@ -472,7 +515,8 @@ def test_format_map_output():
             "missing_percent": 100,
             "partial_unexpected_list": [],
             "unexpected_count": 0,
-            "unexpected_percent": 0.0,
+            "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
             "partial_unexpected_index_list": [],
             "partial_unexpected_counts": [],
@@ -492,15 +536,18 @@ def test_format_map_output():
     unexpected_list = []
     unexpected_index_list = []
 
-    assert df._format_map_output(
-        "BOOLEAN_ONLY",
-        success,
-        element_count,
-        nonnull_count,
-        len(unexpected_list),
-        unexpected_list,
-        unexpected_index_list,
-    ) == {"success": False}
+    assert (
+        df._format_map_output(
+            "BOOLEAN_ONLY",
+            success,
+            element_count,
+            nonnull_count,
+            len(unexpected_list),
+            unexpected_list,
+            unexpected_index_list,
+        )
+        == {"success": False}
+    )
 
     assert df._format_map_output(
         "BASIC",
@@ -519,6 +566,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
         },
     }
@@ -540,6 +588,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
             "partial_unexpected_counts": [],
             "partial_unexpected_index_list": [],
@@ -563,6 +612,7 @@ def test_format_map_output():
             "partial_unexpected_list": [],
             "unexpected_count": 0,
             "unexpected_percent": None,
+            "unexpected_percent_total": None,
             "unexpected_percent_nonmissing": None,
             "partial_unexpected_counts": [],
             "partial_unexpected_index_list": [],
@@ -776,8 +826,18 @@ def test_discard_failing_expectations():
 
 
 def test_test_expectation_function():
-    asset = ge.dataset.PandasDataset({"x": [1, 3, 5, 7, 9], "y": [1, 2, None, 7, 9],})
-    asset_2 = ge.dataset.PandasDataset({"x": [1, 3, 5, 6, 9], "y": [1, 2, None, 6, 9],})
+    asset = ge.dataset.PandasDataset(
+        {
+            "x": [1, 3, 5, 7, 9],
+            "y": [1, 2, None, 7, 9],
+        }
+    )
+    asset_2 = ge.dataset.PandasDataset(
+        {
+            "x": [1, 3, 5, 6, 9],
+            "y": [1, 2, None, 6, 9],
+        }
+    )
 
     def expect_dataframe_to_contain_7(self):
         return {"success": bool((self == 7).sum().sum() > 0)}
