@@ -3,8 +3,8 @@ import warnings
 import pytest
 
 import great_expectations as ge
-from great_expectations.core import (
-    ExpectationConfiguration,
+from great_expectations.core import ExpectationConfiguration
+from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
 from great_expectations.data_context.util import file_relative_path
